==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/STORELOCATION.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "storeid",
    "bin",
    "lot"
})
@XmlRootElement(name = "STORELOCATION")
public class STORELOCATION {

    @XmlElement(name = "STOREID")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN")
    protected String bin;
    @XmlElement(name = "LOT")
    protected String lot;

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété bin.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Définit la valeur de la propriété bin.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Obtient la valeur de la propriété lot.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Définit la valeur de la propriété lot.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/STORELOCATION.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "storeid",
    "bin",
    "lot"
})
@XmlRootElement(name = "STORELOCATION")
public class STORELOCATION {

    @XmlElement(name = "STOREID")
    protected STOREID_Type storeid;
    @XmlElement(name = "BIN")
    protected String bin;
    @XmlElement(name = "LOT")
    protected String lot;

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Sets the value of the lot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

}
